==> react-molecule-validation-code-1.3.0.tgz: package/lib/validationCode.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import PropTypes from 'prop-types';
import PinInput, { getPinInputValueType } from '@s-ui/react-atom-pin-input';
import AtomButton, { atomButtonDesigns } from '@s-ui/react-atom-button';
import ValidationText from '@s-ui/react-atom-validation-text';
import { validationCodeStatus, validationCodeSizes, validationCodeMask } from './config';
import useControlledState from '@s-ui/react-hooks/lib/useControlledState';
import { forwardRef, useMemo } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var normalizeValue = function normalizeValue(value) {
  if (value === undefined) {
    return value;
  }

  return "" + (typeof value === 'string' ? value.split('') : value);
};

var baseClass = 'sui-MoleculeValidationCode';
var MoleculeValidationCode = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _ref$defaultValue = _ref.defaultValue,
      defaultValue = _ref$defaultValue === void 0 ? '' : _ref$defaultValue,
      deleteButtonTextLabel = _ref.deleteButtonTextLabel,
      disabled = _ref.disabled,
      isPassword = _ref.isPassword,
      labelText = _ref.labelText,
      _ref$length = _ref.length,
      length = _ref$length === void 0 ? 6 : _ref$length,
      mask = _ref.mask,
      onChange = _ref.onChange,
      onClear = _ref.onClear,
      onResend = _ref.onResend,
      onSend = _ref.onSend,
      placeholder = _ref.placeholder,
      resendButtonTextLabel = _ref.resendButtonTextLabel,
      sendButtonTextLabel = _ref.sendButtonTextLabel,
      size = _ref.size,
      _ref$footer = _ref.footer,
      Footer = _ref$footer === void 0 ? function (_ref2) {
    var onSubmit = _ref2.onSubmit,
        onResend = _ref2.onResend,
        sendButtonTextLabel = _ref2.sendButtonTextLabel,
        resendButtonTextLabel = _ref2.resendButtonTextLabel;
    return /*#__PURE__*/_jsxs(_Fragment, {
      children: [/*#__PURE__*/_jsx(AtomButton, {
        fullWidth: true,
        onClick: onSubmit,
        isFitted: true,
        children: sendButtonTextLabel
      }), /*#__PURE__*/_jsx(AtomButton, {
        design: atomButtonDesigns.FLAT,
        fullWidth: true,
        onClick: onResend,
        isFitted: true,
        children: resendButtonTextLabel
      })]
    });
  } : _ref$footer,
      status = _ref.status,
      statusMessage = _ref.statusMessage,
      value = _ref.value;

  var _useControlledState = useControlledState(normalizeValue(value), normalizeValue(defaultValue)),
      innerValue = _useControlledState[0],
      setInnerValue = _useControlledState[1];

  var arrayInnerValue = innerValue.length > 0 ? innerValue.split(',') : innerValue;
  var valueType = useMemo(function () {
    return getPinInputValueType({
      value: value,
      defaultValue: defaultValue
    });
  }, [value, defaultValue]);

  var onChangeHandler = function onChangeHandler(event, args) {
    setInnerValue("" + args.innerValue);
    typeof onChange === 'function' && onChange(event, _extends({}, args, {
      value: valueType === 'string' ? args.innerValue.join('') : args.innerValue
    }));
  };

  var onClearHandler = function onClearHandler(event) {
    setInnerValue('');
    typeof onClear === 'function' && onClear(event);
    typeof onChange === 'function' && onChange(event, {
      value: '',
      innerValue: []
    });
  };

  var onHandler = function onHandler(handler) {
    return handler ? function (event) {
      handler(event, {
        value: valueType === 'string' ? arrayInnerValue.filter(Boolean).join('') : arrayInnerValue
      });
    } : undefined;
  };

  return /*#__PURE__*/_jsxs("div", {
    className: baseClass,
    children: [/*#__PURE__*/_jsxs("div", {
      className: baseClass + "-header",
      children: [/*#__PURE__*/_jsx("p", {
        className: baseClass + "-header-labelTitle",
        children: labelText
      }), /*#__PURE__*/_jsx(AtomButton, {
        onClick: onClearHandler,
        design: atomButtonDesigns.FLAT,
        children: deleteButtonTextLabel
      })]
    }), /*#__PURE__*/_jsx("div", {
      className: baseClass + "-inputContainer",
      children: /*#__PURE__*/_jsxs("div", {
        className: baseClass + "-inputContainer-pinInput",
        children: [/*#__PURE__*/_jsx(PinInput, {
          disabled: disabled,
          isPassword: isPassword,
          length: length,
          mask: mask,
          onChange: onChangeHandler,
          placeholder: placeholder,
          ref: forwardedRef,
          size: size,
          status: status,
          value: arrayInnerValue
        }), statusMessage !== undefined && /*#__PURE__*/_jsx(ValidationText, {
          text: statusMessage,
          type: status
        })]
      })
    }), /*#__PURE__*/_jsx("div", {
      className: baseClass + "-footer",
      children: /*#__PURE__*/_jsx(Footer, {
        onSubmit: onHandler(onSend),
        onResend: onHandler(onResend),
        sendButtonTextLabel: sendButtonTextLabel,
        resendButtonTextLabel: resendButtonTextLabel
      })
    })]
  });
});
MoleculeValidationCode.displayName = 'MoleculeValidationCode';
export default MoleculeValidationCode;

==> react-molecule-validation-code-1.4.0.tgz: package/lib/validationCode.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import PropTypes from 'prop-types';
import PinInput, { getPinInputValueType } from '@s-ui/react-atom-pin-input';
import AtomButton, { atomButtonDesigns } from '@s-ui/react-atom-button';
import ValidationText from '@s-ui/react-atom-validation-text';
import { validationCodeStatus, validationCodeSizes, validationCodeMask } from './config';
import useControlledState from '@s-ui/react-hooks/lib/useControlledState';
import { forwardRef, useMemo } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var normalizeValue = function normalizeValue(value) {
  if (value === undefined) {
    return value;
  }

  return "" + (typeof value === 'string' ? value.split('') : value);
};

var baseClass = 'sui-MoleculeValidationCode';
var MoleculeValidationCode = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _ref$defaultValue = _ref.defaultValue,
      defaultValue = _ref$defaultValue === void 0 ? '' : _ref$defaultValue,
      deleteButtonTextLabel = _ref.deleteButtonTextLabel,
      disabled = _ref.disabled,
      isPassword = _ref.isPassword,
      labelText = _ref.labelText,
      _ref$length = _ref.length,
      length = _ref$length === void 0 ? 6 : _ref$length,
      mask = _ref.mask,
      onChange = _ref.onChange,
      onClear = _ref.onClear,
      onResend = _ref.onResend,
      onSend = _ref.onSend,
      placeholder = _ref.placeholder,
      resendButtonTextLabel = _ref.resendButtonTextLabel,
      sendButtonTextLabel = _ref.sendButtonTextLabel,
      size = _ref.size,
      _ref$footer = _ref.footer,
      Footer = _ref$footer === void 0 ? function (_ref2) {
    var onSubmit = _ref2.onSubmit,
        onResend = _ref2.onResend,
        sendButtonTextLabel = _ref2.sendButtonTextLabel,
        resendButtonTextLabel = _ref2.resendButtonTextLabel;
    return /*#__PURE__*/_jsxs(_Fragment, {
      children: [/*#__PURE__*/_jsx(AtomButton, {
        fullWidth: true,
        onClick: onSubmit,
        isFitted: true,
        children: sendButtonTextLabel
      }), /*#__PURE__*/_jsx(AtomButton, {
        design: atomButtonDesigns.FLAT,
        fullWidth: true,
        onClick: onResend,
        isFitted: true,
        children: resendButtonTextLabel
      })]
    });
  } : _ref$footer,
      status = _ref.status,
      statusMessage = _ref.statusMessage,
      value = _ref.value;

  var _useControlledState = useControlledState(normalizeValue(value), normalizeValue(defaultValue)),
      innerValue = _useControlledState[0],
      setInnerValue = _useControlledState[1];

  var arrayInnerValue = innerValue.length > 0 ? innerValue.split(',') : innerValue;
  var valueType = useMemo(function () {
    return getPinInputValueType({
      value: value,
      defaultValue: defaultValue
    });
  }, [value, defaultValue]);

  var onChangeHandler = function onChangeHandler(event, args) {
    setInnerValue("" + args.innerValue);
    typeof onChange === 'function' && onChange(event, _extends({}, args, {
      value: valueType === 'string' ? args.innerValue.join('') : args.innerValue
    }));
  };

  var onClearHandler = function onClearHandler(event) {
    setInnerValue('');
    typeof onClear === 'function' && onClear(event);
    typeof onChange === 'function' && onChange(event, {
      value: '',
      innerValue: []
    });
  };

  var onHandler = function onHandler(handler) {
    return handler ? function (event) {
      handler(event, {
        value: valueType === 'string' ? arrayInnerValue && arrayInnerValue.filter(Boolean).join('') : arrayInnerValue
      });
    } : undefined;
  };

  return /*#__PURE__*/_jsxs("div", {
    className: baseClass,
    children: [/*#__PURE__*/_jsxs("div", {
      className: baseClass + "-header",
      children: [/*#__PURE__*/_jsx("p", {
        className: baseClass + "-header-labelTitle",
        children: labelText
      }), /*#__PURE__*/_jsx(AtomButton, {
        onClick: onClearHandler,
        design: atomButtonDesigns.FLAT,
        children: deleteButtonTextLabel
      })]
    }), /*#__PURE__*/_jsx("div", {
      className: baseClass + "-inputContainer",
      children: /*#__PURE__*/_jsxs("div", {
        className: baseClass + "-inputContainer-pinInput",
        children: [/*#__PURE__*/_jsx(PinInput, {
          disabled: disabled,
          isPassword: isPassword,
          length: length,
          mask: mask,
          onChange: onChangeHandler,
          placeholder: placeholder,
          ref: forwardedRef,
          size: size,
          status: status,
          value: arrayInnerValue
        }), statusMessage !== undefined && /*#__PURE__*/_jsx(ValidationText, {
          text: statusMessage,
          type: status
        })]
      })
    }), /*#__PURE__*/_jsx("div", {
      className: baseClass + "-footer",
      children: /*#__PURE__*/_jsx(Footer, {
        onSubmit: onHandler(onSend),
        onResend: onHandler(onResend),
        sendButtonTextLabel: sendButtonTextLabel,
        resendButtonTextLabel: resendButtonTextLabel
      })
    })]
  });
});
MoleculeValidationCode.displayName = 'MoleculeValidationCode';
export default MoleculeValidationCode;
